@@ -2,5 +2,6 @@
 
 from .base import BaseLLM
 from .openai import OpenAILLM
+from .prompts import AgenticPrompts, default_prompts
 
-__all__ = ["BaseLLM", "OpenAILLM"]
+__all__ = ["BaseLLM", "OpenAILLM", "AgenticPrompts", "default_prompts"]
